@@ -27,7 +27,7 @@ static void mk_storage_spec(MVMThreadContext *tc, MVMuint16 bits, MVMuint16 is_u
 static MVMObject * type_object_for(MVMThreadContext *tc, MVMObject *HOW) {
     MVMSTable *st  = MVM_gc_allocate_stable(tc, &P6int_this_repr, HOW);
 
-    MVMROOT(tc, st, {
+    MVMROOT(tc, st) {
         MVMObject *obj = MVM_gc_allocate_type_object(tc, st);
         MVMP6intREPRData *repr_data = (MVMP6intREPRData *)MVM_malloc(sizeof(MVMP6intREPRData));
 
@@ -38,7 +38,7 @@ static MVMObject * type_object_for(MVMThreadContext *tc, MVMObject *HOW) {
         st->size = sizeof(MVMP6int);
         st->REPR_data = repr_data;
 
-    });
+    }
 
     return st->WHAT;
 }
@@ -96,6 +96,10 @@ MVMint64 MVMP6int_get_int(MVMThreadContext *tc, MVMSTable *st, MVMObject *root,
     }
 }
 
+MVMint16 MVMP6int_is_unsigned(MVMSTable *st) {
+    return ((MVMP6intREPRData *)st->REPR_data)->is_unsigned;
+}
+
 /* Marks the representation data in an STable.*/
 static void gc_free_repr_data(MVMThreadContext *tc, MVMSTable *st) {
     MVM_free(st->REPR_data);
